@@ -291,6 +291,15 @@ void FrameSvg::getMargins(qreal &left, qreal &top, qreal &right, qreal &bottom)
     bottom = d->frame->bottomMargin;
 }
 
+QMarginsF FrameSvg::margins() const
+{
+    if (!d->frame || d->frame->noBorderPadding) {
+        return QMarginsF();
+    } else {
+        return QMarginsF(d->frame->leftMargin, d->frame->topMargin, d->frame->rightMargin, d->frame->bottomMargin);
+    }
+}
+
 void FrameSvg::getFixedMargins(qreal &left, qreal &top, qreal &right, qreal &bottom) const
 {
     if (!d->frame || d->frame->noBorderPadding) {
@@ -304,6 +313,15 @@ void FrameSvg::getFixedMargins(qreal &left, qreal &top, qreal &right, qreal &bot
     bottom = d->frame->fixedBottomMargin;
 }
 
+QMarginsF FrameSvg::fixedMargins() const
+{
+    if (!d->frame || d->frame->noBorderPadding) {
+        return QMarginsF();
+    } else {
+        return QMarginsF(d->frame->fixedLeftMargin, d->frame->fixedTopMargin, d->frame->fixedRightMargin, d->frame->fixedBottomMargin);
+    }
+}
+
 void FrameSvg::getInset(qreal &left, qreal &top, qreal &right, qreal &bottom) const
 {
     if (!d->frame || d->frame->noBorderPadding) {
@@ -317,6 +335,15 @@ void FrameSvg::getInset(qreal &left, qreal &top, qreal &right, qreal &bottom) co
     bottom = d->frame->insetBottomMargin;
 }
 
+QMarginsF FrameSvg::insets() const
+{
+    if (!d->frame || d->frame->noBorderPadding) {
+        return QMarginsF();
+    } else {
+        return QMarginsF(d->frame->insetLeftMargin, d->frame->insetTopMargin, d->frame->insetRightMargin, d->frame->insetBottomMargin);
+    }
+}
+
 QRectF FrameSvg::contentsRect() const
 {
     if (d->frame) {
@@ -444,7 +471,7 @@ int FrameSvg::minimumDrawingWidth()
     return 0;
 }
 
-//#define DEBUG_FRAMESVG_CACHE
+// #define DEBUG_FRAMESVG_CACHE
 FrameSvgPrivate::~FrameSvgPrivate() = default;
 
 QPixmap FrameSvgPrivate::alphaMask()
@@ -911,7 +938,7 @@ void FrameSvgPrivate::updateSizes(FrameData *frame) const
     // converting that to a QString temporary for the replace operation.
     // Additionally, we use a template parameter to provide us the compile-time
     // length of the literal so we don't need to calculate that.
-    auto createName = [&nameBuffer, offset]<std::size_t length>(const char16_t(&name)[length]) {
+    auto createName = [&nameBuffer, offset]<std::size_t length>(const char16_t (&name)[length]) {
         nameBuffer.replace(offset, length - 1, reinterpret_cast<const QChar *>(name), length);
         return QStringView(nameBuffer).mid(0, offset + length - 1);
     };
